# BIT.py


def main(sheet, filepath1, filepath2, filepath3, filepath4, period_num):
    if sheet == 'sheet2':
        from pmipy.BITauto import BIT_sheet2
        BIT_sheet2.BIT_automation(filepath1, filepath2, filepath3, filepath4, period_num)
    elif sheet == 'sheet3':
        from pmipy.BITauto import BIT_sheet3
        BIT_sheet3.BIT_automation(filepath1, filepath2, filepath3, filepath4, period_num)
    elif sheet == 'sheet4':
        from pmipy.BITauto import BIT_sheet4
        BIT_sheet4.BIT_automation(filepath1, filepath2, filepath3, filepath4, period_num)
    elif sheet == 'sheet5':
        from pmipy.BITauto import BIT_sheet5
        BIT_sheet5.BIT_automation(filepath1, filepath2, filepath3, filepath4, period_num)
    elif sheet == 'sheet6':
        from pmipy.BITauto import BIT_sheet6
        BIT_sheet6.BIT_automation(filepath1, filepath2, filepath3, filepath4, period_num)
    elif sheet == 'sheet7':
        from pmipy.BITauto import BIT_sheet7
        BIT_sheet7.BIT_automation(filepath1, filepath2, filepath3, filepath4, period_num)
    elif sheet == 'all':
        from pmipy.BITauto import BIT_sheet2
        from pmipy.BITauto import BIT_sheet3
        from pmipy.BITauto import BIT_sheet4
        from pmipy.BITauto import BIT_sheet5
        from pmipy.BITauto import BIT_sheet6
        from pmipy.BITauto import BIT_sheet7
        BIT_sheet2.BIT_automation(filepath1, filepath2, filepath3, filepath4, period_num)
        BIT_sheet3.BIT_automation(filepath1, filepath2, filepath3, filepath4, period_num)
        BIT_sheet4.BIT_automation(filepath1, filepath2, filepath3, filepath4, period_num)
        BIT_sheet5.BIT_automation(filepath1, filepath2, filepath3, filepath4, period_num)
        BIT_sheet6.BIT_automation(filepath1, filepath2, filepath3, filepath4, period_num)
        BIT_sheet7.BIT_automation(filepath1, filepath2, filepath3, filepath4, period_num)
    else:
        print("请输入正确的sheet！")


# ---------------------------------------------------------------------------------------------------------------------#
# AUTHOR: Jason, jinxiang_zhu@parramountain.com                                                                        #
# ORGANIZATION: PMI                                                                                                    #
# VERSION: 1.0                                                                                                         #
# CREATED: 3rd Mar 2016                                                                                                #
# ---------------------------------------------------------------------------------------------------------------------#

import os
import pandas as pd

#import seaborn as sns
#import matplotlib.pyplot as plt
#from sklearn.preprocessing import StandardScaler

"""Tnseq command line interface """

# =============== <1: Realization of shell scripts using click package> #==============#
import click

VERSION = '0.12'
CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])


@click.group(context_settings=CONTEXT_SETTINGS)
@click.version_option(version=VERSION)
def main():
    pass


@main.command(help='OCM参数可视化分析')
@click.option('--data_path', '-f', default='湖北人口_ocm1.5.csv', help="输入待分析的OCM文件路径，默认为“湖北人口_ocm1.5.csv”")
@click.option('--tag', '-t', default='湖北人口', help='用于存放输出文件的文件夹，默认为“湖北人口”')
def OCM_Visual(**kwargs):
    from pmipy import OCMVisualization
    data_path = kwargs['data_path']
    tag = kwargs['tag']
    path =os.path.dirname(OCMVisualization.__file__)  # OCMFeatureExtract模块所在的路径
    OCMVisualization.run_Rscript(data_path, tag, path)


@main.command(help='提取OCM参数')
@click.option('--data_path', '-f', default='湖北需求预估使用的参数.xlsx', help='输入待提取的参数信息文件路径，默认为“湖北需求预估使用的参数.xlsx”')
@click.option('--province', '-p', default='湖北', help='选择提取的省份，默认为湖北')
def OCM_extract(**kwargs):
    from pmipy import OCMFeatureExtract
    feature_file = kwargs['data_path']
    province = kwargs['province']
    df = pd.read_excel(feature_file, index_col=[0])  # 将'省'列设为索引
    OCMFeatureExtract.merging_data(df, province)


@main.command(help='分析销售数据或OCM参数')
@click.option('--data_path', '-f', default='福州上海子公司业绩表.xlsx', help='分析数据的文件路径')
@click.option('--index', '-i', default='餐厅名称', help='选择某列作为数据框的索引')
@click.option('--value_col', '-vc', default=5, help='选择用于数据标准化处理的开始列数')
def feature_analysis(**kwargs):
    data_path = kwargs['data_path']
    index = kwargs['index']
    value_col = kwargs['value_col']
    df = pd.read_excel(data_path, index_col=index)
    print(df.head())


@main.command(help='BIT自动化程序')
@click.option('--file_path1', '-f1', default='ts2.xlsx', help='待写入的excel文件路径，默认为“ts2.xlsx”')
@click.option('--file_path2', '-f2', default='MR002-170802Y-德克士Brand Image Tracking（W45-W48）（11月）数据v2.xlsx', 
help='问卷信息文件（已初步清洗的excel文件）路径，默认为“MR002-170802Y-德克士Brand Image Tracking（W45-W48）（11月）数据v2.xlsx”')
@click.option('--file_path3', '-f3', default='qa-Olivia.xlsx', help='问卷题目编号信息文件路径，如未来题目有变动，需更新此文件信息，默认为“qa-Olivia.xlsx”')
@click.option('--file_path4', '-f4', default='新配额分布.xlsx', help='城市配额/权重文件路径，默认为“新配额分布.xlsx”')
@click.option('--sheet', '-s', default='sheet2', help='选择待填写的sheet。sheet2:<2.外食情况>;sheet3:<3.品牌与广告知名度>;sheet4:<4.品牌购买与食用>;\
sheet5:<5.西式快餐U&A >;sheet6:<6.重要指标汇总>;sheet7:<7.样本资料>，如填写“all”，则表示写入所有sheet。默认为“sheet2”')
@click.option('--period_num', '-p', default=4, help='输入阶段数，默认为4')
def BIT(**kwargs):
    from pmipy import BIT
    filepath1 = kwargs['file_path1']
    filepath2 = kwargs['file_path2']
    filepath3 = kwargs['file_path3']
    filepath4 = kwargs['file_path4']
    sheet = kwargs['sheet']
    period_num = kwargs['period_num']
    BIT.main(sheet, filepath1, filepath2, filepath3, filepath4, period_num)


@main.command(help='需求预估（商圈分级）')
@click.option('--work_dir', '-wd', default='.', help='输入数据的存放目录，默认为当前工作目录')
@click.option('--sales_file_ori', '-sfo', default='湖北业绩信息1218.xlsx', help='销售数据的初始文件路径，默认为“湖北业绩信息1218.xlsx”')
@click.option('--sales_file_proc', '-sfp', default='', help='处理过的销售数据路径，如存在则程序会无视sales_file_ori文件，默认不存在')
@click.option('--ocm_file', '-of', default='湖北_OCM参数.xlsx', help='OCM参数的文件路径，默认为“湖北_OCM参数.xlsx”')
@click.option('--feature_file', '-ff', default='', help='OCM参数的名单路径，默认不填')
@click.option('--province', '-p', default='湖北', help='选择预测的省份，默认为湖北')
def demand_predict(**kwargs):
    from pmipy import demand_predict
    work_dir = kwargs['work_dir']
    sales_file_ori = kwargs['sales_file_ori']
    sales_file_proc = kwargs['sales_file_proc']
    ocm_file = kwargs['ocm_file']
    feature_file = kwargs['feature_file']
    province = kwargs['province']
    demand_predict.main(work_dir, province, sales_file_ori, sales_file_proc, ocm_file, feature_file)


# ================================== <4: Running main function> ================================== #
if __name__ == '__main__':
    # logger = log.createCustomLogger('root')
    main()





import os, sys
import time
import numpy as np
import pandas as pd
import seaborn as sns
import matplotlib as mpl
import matplotlib.pyplot as plt
from pyplotz.pyplotz import PyplotZ


zhfont1 = mpl.font_manager.FontProperties(fname='C:\Windows\Fonts\simkai.ttf')


class SnsVisualization(object):
    def __init__(self, work_dir, data_file, time_tag=time.strftime("%Y-%m-%d-%Hh%Mm", time.localtime())):
        self.work_dir = work_dir
        self.data_file = data_file
        self.time_tag = time_tag
        file_suffix = os.path.splitext(data_file)[-1]
        if not os.path.exists(self.time_tag):
            os.mkdir(self.time_tag)
        if '.xls' in file_suffix:
            self.df = pd.read_excel(os.path.join(work_dir, data_file))
        elif file_suffix == '.csv':
            self.df = pd.read_csv(os.path.join(work_dir, data_file))
        else:
            self.df = pd.read_table(os.path.join(work_dir, data_file))

    def plot(self):
        df1 = pd.read_excel("2017-11-08-23h32m_median.xlsx")
        df2 = pd.read_excel("2017-11-08-23h32m_mean.xlsx")
        df1.sort_values(by=["sales_avg"], inplace=True)
        df2.sort_values(by=["sales_avg"], inplace=True)
        max1 = df1["sales_avg"].max() if df1["sales_avg"].max() > df1["sales_pred"].max() else df1["sales_pred"].max()
        max2 = df2["sales_avg"].max() if df2["sales_avg"].max() > df2["sales_pred"].max() else df2["sales_pred"].max()
        max = int(max1)+1 if max1 > max2 else int(max2)+1
        sns.set_style("whitegrid")
        plt.plot(np.arange(max), linestyle="--")
        plt.scatter(df1["sales_avg"], df1["sales_pred"], c='r')
        plt.scatter(df2["sales_avg"], df2["sales_pred"], c='b', marker="+")
        plt.savefig("2017-11-08-23h32m_sales_pred")

    def correlation_analysis(self, factor1, factor2, df, tag, kind='reg', title=''):
        # 判断文件类型，用适合的pandas读取器读取数据
        # 直方图的双变量类似物被称为“hexbin”图，因为它显示了落在六边形仓内的观测数
        pltz = PyplotZ()
        pltz.enable_chinese()
        sns.jointplot(x=factor1, y=factor2, data=df, kind=kind)
        pltz.xlabel(factor1)
        pltz.ylabel(factor2)
        pltz.title(title)
        plt.savefig(os.path.join(self.time_tag, "%s&%s_jointplot_%s_%s_%s" % (factor1, factor2, kind, tag, self.time_tag)))
        plt.close()
        """g = sns.jointplot(x=factor1, y=factor2, data=df, kind="kde", color="m")
        g.plot_joint(plt.scatter, c="w", s=30, linewidth=1, marker="+")
        g.ax_joint.collections[0].set_alpha(0)
        g.set_axis_labels("$X$", "$Y$")
        plt.show()"""

    def heatmap(self, df, xlabel, ylabel, title='', annot=False, cmap=None):
        f, ax = plt.subplots(figsize=(15, 12))
        # 解决中文乱码问题
        pltz = PyplotZ()
        pltz.enable_chinese()
        plt.xticks(fontproperties=zhfont1)  # rotation='90',
        plt.yticks(fontproperties=zhfont1)
        sns.heatmap(df, square=False, linewidths=.5, annot=annot, cmap=cmap)
        pltz.xlabel(xlabel)
        pltz.ylabel(ylabel)
        pltz.title(title)
        plt.savefig(os.path.join(self.time_tag, "%s_%s_heatmap_%s" % (xlabel, ylabel, self.time_tag)), bbox_inches='tight', pad_inches=0.2)
        plt.close()

    def correlation_heatmap(self, internal_chars=[], annot=False, cmap=None):
        tag = os.path.splitext(self.data_file)[0]
        corrmat = self.df[internal_chars].corr() if internal_chars else self.df.corr()
        self.heatmap(corrmat, tag, "correlation", annot, cmap)

    def boxplot(self, x, y, hue=None):
        tag = os.path.splitext(self.data_file)[0]
        pltz = PyplotZ()
        pltz.enable_chinese()
        sns.set_style("whitegrid")  # sns.set(style="ticks")
        plt.xticks(fontproperties=zhfont1)
        plt.yticks(fontproperties=zhfont1)
        sns.boxplot(x=x, y=y, hue=hue, data=self.df, palette="PRGn")
        pltz.xlabel(x)
        pltz.ylabel(y)
        plt.savefig(os.path.join(self.time_tag, "%s_boxplot_%s" % (tag, self.time_tag)))
        plt.close()
        """sns.swarmplot(x=x, y=y, hue=hue, data=self.df)
        plt.savefig(os.path.join(self.time_tag, "%s_swarmplot_%s" % (tag, self.time_tag)))
        plt.close()
        sns.violinplot(x=x, y=y, hue=hue, data=self.df, palette="muted")
        plt.savefig(os.path.join(self.time_tag, "%s_violinplot_%s" % (tag, self.time_tag)))
        plt.close()"""


if __name__ == "__main__":
    work_dir = "."
    data_file = "2017-11-08-23h32m_权重值.xlsx"
    vl = SnsVisualization(work_dir, data_file)
    # parameter = '从众适用型比例,理智务实型比例,点评最低(3元以下)-比例,点评中低(3-27元)-比例,人口总数,区域数量,平方米均日租金,平方米每户均单价,旅游景点,教育培训,火锅,烧烤,川菜,咖啡厅'
    parameter = "人口总数；医疗；金融；酒店；火锅；购物；汽车服务；休闲娱乐；川菜；生活服务；政府机构；美食；" \
                "公司企业；交通设施；湘菜；大众门店总数；运动健身；文化传媒；面包甜点；烧烤；西餐；咖啡厅；教育培训；" \
                "房地产；大众门店均单价；小吃快餐；旅游景点；行政地标；区域数量"
    internal_chars = parameter.split('；') + ['sales_avg'] #;sys.exit(internal_chars)
    df = pd.read_excel(os.path.join(work_dir, data_file))
    df.set_index("参数", inplace=True)
    tag = os.path.splitext(data_file)[0]
    vl.heatmap(df, tag, annot=True, cmap="RdYlGn")
    #vl.plot()




import os
import sys
import numpy as np
import pandas as pd
import xlwings as xw


# 必用表头列表
CODE = 'CODE'
city_tag='S1'
sex_tag='S4'
age_tag='RES5'
rsjd_tag = 'rsjd'
list_essential1 = [CODE, city_tag, sex_tag, age_tag, rsjd_tag]
brand_list = ['肯德基', '德克士', '麦当劳', '华莱士', '汉堡王', '其他', '必胜客']
advertising_list = ['门店海报', '电视广告', '网络视频网站', '公交车候车亭', '公交车车身', '楼宇电梯广告', '微信', '微博', '其他，请注明', '不记得（与其他选项互斥）']


# 提取QA1和QA2
def extract_data1(qtag_list):
    # 这里加入'CODE',以便统计每个分组的总数
    qtag_list.insert(0, CODE)
    # 按不同类别进行分组
    gb_city = df.groupby(city_tag)
    gb_sex = df.groupby(sex_tag)
    gb_age = df.groupby(age_tag)
    df_city = gb_city.count().loc[:, qtag_list]
    # 基于df_city数据计算sheet <2.外食情况> 周期数据
    df_period = df_city
    # 使用各城市权重进行校正
    df_period1 = df_weight.merge(df_period, left_index=True,right_index=True)
    df_period2 = df_period1.drop(['权重', CODE], axis=1).apply(lambda x: x*df_period1['权重'])
    total_list = list(df_period2.sum() / len(df))   # base
    # 在列表开头部分插入总问卷数Base
    total_list.insert(0, df_period1[CODE].sum())
    # 计算每个城市的问卷数
    df_city = df_city.T
    df_city = pd.concat([pd.DataFrame(df_city.loc[CODE]).T,df_city.drop(CODE).apply(lambda x: x / df_city.loc[CODE], axis=1)])
    # 计算不同性别分布
    df_sex = gb_sex.count().loc[:, qtag_list].T
    df_sex = pd.concat([pd.DataFrame(df_sex.loc[CODE]).T,df_sex.drop(CODE).apply(lambda x: x / df_sex.loc[CODE], axis=1)])
    # 计算不同年龄段分布
    df_age = gb_age.count().loc[:, qtag_list].T
    df_age = pd.concat([pd.DataFrame(df_age.loc[CODE]).T,df_age.drop(CODE).apply(lambda x: x / df_age.loc[CODE], axis=1)])
    # 按'人生阶段'进行分组
    gb_rsjd = df.groupby(rsjd_tag)
    df_rsjd = gb_rsjd.count().loc[:, qtag_list].T
    df_rsjd = pd.concat([pd.DataFrame(df_rsjd.loc[CODE]).T,df_rsjd.drop(CODE).apply(lambda x: x / df_rsjd.loc[CODE], axis=1)])

    return total_list, df_city, df_sex, df_age, df_rsjd


# 从excel中提取含显著性标记的数字矩阵, col_num指填入列的
def extract_digit(sht, period_num, row_num, col_num, vertical_length, data_list):
    df_digit = pd.DataFrame(sht.range((row_num, col_num),(row_num+vertical_length, col_num+period_num-1)).value)
    # 去除非数字字符串，提取数字
    def format_data(x):
        if '%(' in str(x):
            x = float(x.split('%(')[0]) / 100
        return x
    df_digit = df_digit.applymap(format_data)
    # 将字符串'-'和0 替换为缺失值NaN，确保计算平均值时不考虑数据缺失的样本
    df_digit.replace('-', np.nan, inplace=True)
    df_digit.replace('0', np.nan, inplace=True)
    df_digit[period_num-1] = data_list
    base_temp = list(df_digit.loc[0])  # 注：base_temp为列表类型时，写入excel表时才会按行的方向输入
    df_digit_percent = df_digit.drop(0)

    return df_digit_percent, base_temp


def mark_significance(df_percent, base_temp, sht, row_num, col_num):

    # Z-test函数
    def ztest(p1, p2, n1, n2):
        z = abs((p1 - p2) / np.sqrt((n1 * p1 + n2 * p2) * (n1 * (1 - p1) + n2 * (1 - p2)) / (n1 * n2) / (n1 + n2)))
        return z > 1.959963985

    df_percent.replace('-', np.nan, inplace=True)
    for index, row in enumerate(df_percent.values):
        p1_proc_list = []
        for index1, (p1, n1) in enumerate(zip(row, base_temp)):
            p1_proc = '%.0f' % (p1 * 100) + "%("  # 有显著的数值不保留小数点后有效数字
            tag_significance = False
            for index2, (p2, n2) in enumerate(zip(row, base_temp)):
                if p1 > p2:
                    if ztest(p1, p2, n1, n2):
                        # p1高于p2且显著时，在p1后面标记p2的位置
                        p1_proc = p1_proc + chr(index2+97).upper()
                        # 如果p1有经过标记处理，则tag_significance为True
                        tag_significance = True
            if tag_significance:
                p1_proc += ")"
            else:
                p1_proc = p1
            
            if type(p1_proc) == str:
                # 写入显著性数值
                sht.range(row_num+index+1, index1+col_num).value = p1_proc
                sht.range(row_num+index+1, index1+col_num).color = (253,245,230)
            else:
                if np.isnan(p1_proc): # 判断缺失值的唯一方法,注意np.isnan('94%(D)')会报错
                    # 写入缺失数据
                    p1_proc = '-'
                    sht.range(row_num+index+1, index1+col_num).value = p1_proc
                    sht.range(row_num+index+1, index1+col_num).color = (169,169,169)
                else:
                    sht.range(row_num+index+1, index1+col_num).value = p1_proc
                    sht.range(row_num+index+1, index1+col_num).color = (255,255,255)


def period_proc1(qtag, sht, period_num, row_num, col_num_starting, vertical_length, total_list):
    # 获取各周期数据
    period_file = '%s_period_data.xlsx' % qtag
    if os.path.exists(period_file):
        df_total = pd.read_excel(period_file, usecols=period_num-2)
        df_total[period_num-1] = data_list
        df_total_percent, total_temp = df_total.drop(0), list(df_total.loc[0])
    else:
        df_total_percent, total_temp = extract_digit(sht, period_num, row_num, col_num_starting, vertical_length, total_list)
    
    # 加入新周期total信息时，需保存信息数据
    df_total = pd.concat([pd.DataFrame(total_temp).T, df_total_percent])
    #======df_total.to_excel(period_file, index=False)
    # 计算sheet Total列数据
    total_percent_list = []
    df_total2 = df_total_percent.apply(lambda x: x * total_temp, axis=1)
    for row in df_total2.values:
        i_sum, j_sum = 0, 0
        for i, j in zip(row, total_temp):
            if i > 0:
                i_sum += i
                j_sum += j
        total_percent_list.append(i_sum / j_sum)

    total_percent_list.insert(0, sum(total_temp))
    # 将df_total['sum']列写入sheet <2.外食情况>的 Total列
    sht.range(row_num, col_num_starting-1).options(transpose=True).value = total_percent_list
    # 写入Base行
    sht.range(row_num, col_num_starting).value = total_temp
    # 标记显著性数值，并写入sheet <2.外食情况>
    mark_significance(df_total_percent, total_temp, sht, row_num, col_num_starting)


# 各维度分析问卷结果
def dimension_proc(df_dimens, complete_dimens_list, vertical_length):
    for index, dimens in enumerate(complete_dimens_list):
        try:
            dimens_list = list(df_dimens[dimens])
        except:
            # dimens_list包含base数据，因此行数为vertical_length + 1
            dimens_list = ['-'] * (vertical_length + 1)
        if not index:
            df_dimens_proc = pd.DataFrame(dimens_list)
        else:
            df_dimens_proc[index] = dimens_list
    return df_dimens_proc


# 处理城市、性别、年龄段和人生阶段
def csar_proc1(qtag, sht, period_num, row_num, col_num_starting, vertical_length, df_city, df_sex, df_age, df_rsjd):
    # 按Excel顺序填入城市信息
    complete_city_list = ['成都', '哈尔滨', '西安', '郑州', '福州', '杭州']
    df_city_proc = dimension_proc(df_city, complete_city_list, vertical_length)
    for index, column in enumerate(df_city_proc.columns):
        # city_file = '%s_period_%s_data.xlsx' % qtag 这个功能后面再添加
        # 使用col_num2跟踪移动列
        col_num2 = col_num_starting + period_num * (index + 1)
        df_digit_percent, base_temp = extract_digit(sht, period_num, row_num, col_num2, vertical_length, df_city_proc[column])
        # 先写入base数据
        sht.range(row_num, col_num2).value = base_temp
        # 标记显著性数值，并写入sheet <2.外食情况>
        mark_significance(df_digit_percent, base_temp, sht, row_num, col_num2)

    # 按顺序填入性别信息，***性别没有考虑缺失数据的情况
    complete_sex_list = ['男性', '女性']
    df_sex_proc = dimension_proc(df_sex, complete_sex_list, vertical_length)
    for column in df_sex_proc.columns:
        index += 1  # 使用col_num2跟踪移动列
        col_num2 = col_num_starting + period_num * (index + 1)
        df_digit_percent, base_temp = extract_digit(sht, period_num, row_num, col_num2, vertical_length, df_sex_proc[column])
        # 先写入base数据
        sht.range(row_num, col_num2).value = base_temp
        # 标记显著性数值，并写入sheet <2.外食情况>
        mark_significance(df_digit_percent, base_temp, sht, row_num, col_num2)

    # 按顺序填入各年龄段信息
    complete_age_list = ['15-19岁', '20-24岁', '25-29岁', '30-34岁', '35-39岁']
    df_age_proc = dimension_proc(df_age, complete_age_list, vertical_length)
    for column in df_age_proc.columns:
        index += 1  # 使用col_num2跟踪移动列
        col_num2 = col_num_starting + period_num * (index + 1)
        df_digit_percent, base_temp = extract_digit(sht, period_num, row_num, col_num2, vertical_length, df_age_proc[column])
        # 先写入base数据
        sht.range(row_num, col_num2).value = base_temp
        # 标记显著性数值，并写入sheet <2.外食情况>
        mark_significance(df_digit_percent, base_temp, sht, row_num, col_num2)

    # 按人生阶段填入各年龄段信息
    complete_rsjd_list = ['青少年&学生', '青年', '壮年', '家庭']
    df_rsjd_proc = dimension_proc(df_rsjd, complete_rsjd_list, vertical_length)
    for column in df_rsjd_proc.columns:
        index += 1  # 使用col_num2跟踪移动列
        col_num2 = col_num_starting + period_num * (index + 1)
        df_digit_percent, base_temp = extract_digit(sht, period_num, row_num, col_num2, vertical_length, df_rsjd_proc[column])
        # 先写入base数据
        sht.range(row_num, col_num2).value = base_temp
        # 标记显著性数值，并写入sheet <2.外食情况>
        mark_significance(df_digit_percent, base_temp, sht, row_num, col_num2)


def processing_type1(qtag, sht, period_num, row_num, col_num_starting):
    ## col_num_starting为起始单元格的列
    qtag_list = list(df_qa.loc[qtag].dropna())
    vertical_length = len(qtag_list)
    total_list, df_city, df_sex, df_age, df_rsjd = extract_data1(qtag_list)
    # 处理并填入"周期"信息
    period_proc1(qtag, sht, period_num, row_num, col_num_starting, vertical_length, total_list)

    csar_proc1(qtag, sht, period_num, row_num, col_num_starting, vertical_length, df_city, df_sex, df_age, df_rsjd)


def BIT_automation(filepath1, filepath2, filepath3, filepath4, period_num):
    global wb, df, df_qa, df_weight, Base
    # 提取问卷数据
    ## 打开问卷信息文件，该数据已经清洗过 
    df = pd.read_excel(filepath2)
    ## 提取问卷题目编号信息文件，如未来题目有变动，需更新此文件信息
    df_qa = pd.read_excel(filepath3, index_col=0)
    ## 获取配额/权重
    df_weight = pd.read_excel(filepath4, index_col=0)
    Base = len(df) # Base即为行数，也就是问卷数
    # 给"人生阶段"打标签
    # 统计“人生阶段”，青少年&学生（消费者15-24岁，没有小孩或小孩2岁以下）;青年（消费者25-29岁，没有小孩或小孩2岁以下）;
    # 壮年（消费者30-39岁，没有小孩或小孩2岁以下）;家庭（小孩3岁以上）
    # 第一步：给150份问卷打标签
    df[rsjd_tag] = '家庭'
    df.loc[(df.S5.isin(['15-19岁', '20-24岁'])) & df.D2.isin(['未婚','已婚，无小孩','已婚，小孩0岁~2岁']), rsjd_tag] = '青少年&学生'
    df.loc[(df.S5 == '25-29岁') & df.D2.isin(['未婚','已婚，无小孩','已婚，小孩0岁~2岁']), rsjd_tag] = '青年'
    df.loc[(df.S5.isin(['30-34岁', '35-39岁'])) & df.D2.isin(['未婚','已婚，无小孩','已婚，小孩0岁~2岁']), rsjd_tag] = '壮年'

    # 统计各标签的base
    df_base = df.loc[:, list_essential1]
    city_base = pd.pivot_table(df_base, columns=[city_tag], values=[CODE], aggfunc=np.size).loc[CODE]
    sex_base = pd.pivot_table(df_base, columns=[sex_tag], values=[CODE], aggfunc=np.size).loc[CODE]
    age_base = pd.pivot_table(df_base, columns=[age_tag], values=[CODE], aggfunc=np.size).loc[CODE]
    rsjd_base = pd.pivot_table(df_base, columns=[rsjd_tag], values=[CODE], aggfunc=np.size).loc[CODE]

    # 打开Excel程序
    app=xw.App(visible=True,add_book=False)
    # 打开已存在的文件
    wb = app.books.open(filepath1)

    # 读取<2.外食情况> sheets
    sht2 = wb.sheets['2.外食情况']
    # 将QA1和QA2的数据填入<2.外食情况> sheets
    processing_type1('QA1', sht2, period_num, 6, 3)
    processing_type1('QA2', sht2, period_num, 39, 3)


if __name__ == "__main__":
    BIT_automation(filepath1, filepath2, filepath3, filepath4, period_num)





